'use client';

import { useState, useEffect } from 'react';
import Link from 'next/link';
import { Menu, X, ExternalLink } from 'lucide-react';
import { ThemeToggle } from './ThemeToggle';
import { headerLinks } from '@/data/social';

export function Navigation() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      const target = event.target as HTMLElement;
      if (!target.closest('.menu-toggle') && !target.closest('.nav-links') && isMenuOpen) {
        setIsMenuOpen(false);
      }
    };

    document.addEventListener('click', handleClickOutside);
    return () => document.removeEventListener('click', handleClickOutside);
  }, [isMenuOpen]);

  return (
    <nav aria-label="Main navigation">
      <div className="container">
        <Link href="/" className="logo">./charlotte.sh</Link>

        <button
          className="menu-toggle"
          aria-expanded={isMenuOpen}
          aria-controls="primary-menu"
          aria-label="Toggle menu"
          onClick={() => setIsMenuOpen(!isMenuOpen)}
        >
          {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
        </button>

        <ul className={`nav-links ${isMenuOpen ? 'menu-open' : ''}`} id="primary-menu">
          {headerLinks.map((link) => (
            <li key={link.name}>
              <a href={link.url} target="_blank" rel="noopener noreferrer">
                {link.name} <ExternalLink className="icon-small" />
                <span className="visually-hidden">(opens in new tab)</span>
              </a>
            </li>
          ))}
          <li>
            <ThemeToggle />
          </li>
        </ul>
      </div>
    </nav>
  );
}